@@ -19,7 +19,7 @@ HASH = 15
 MULTILINE = 16
 EVERYTHING = 17
 TILDA = 18
-
+HASHROCKET = 19
 
 TOKEN_NAMES = {
     value: name for name, value in globals().items()
@@ -31,14 +31,15 @@ __all__.extend(TOKEN_NAMES.values())
 
 
 EXACT_TOKENS = [
-    ('->',  RARROW),
-    ('@',   AT),
-    (':',   COLON),
-    ('\\',  BACKSLASH),
-    ('|',   PIPE),
-    ('~',   TILDA),
-    ('#',   HASH),
-    ('.',   DOT),
+    ('->', RARROW),
+    ('=>', HASHROCKET),
+    ('@', AT),
+    (':', COLON),
+    ('\\', BACKSLASH),
+    ('|', PIPE),
+    ('~', TILDA),
+    ('#', HASH),
+    ('.', DOT),
 ]
 EXACT_TOKENS_DICT = {value: string for string, value in EXACT_TOKENS}
 
